@@ -8,7 +8,7 @@ use PortageXS;
 my $pxs=PortageXS->new();
 my @repos=();
 
-push(@repos,$pxs->getPortdir());
+push(@repos,$pxs->portdir());
 push(@repos,$pxs->getPortdirOverlay());
 
 foreach (@repos) {
