@@ -7,6 +7,9 @@ use PortageXS;
 
 my $pxs=PortageXS->new();
 
+if ( not $ARGV[0]) {
+    die "searchPackage.pl <packagename>";
+}
 print "Search for packages where package name is like: $ARGV[0]\n";
 print join("\n",$pxs->searchPackage($ARGV[0],'like'))."\n";
 
