@@ -4,12 +4,13 @@ use warnings;
 use strict;
 
 use PortageXS::UI::Spinner;
+use Time::HiRes qw(sleep);
 
 print "Spinner demonstration..  ";
 my $spinner=PortageXS::UI::Spinner->new();
-for (my $i=0;$i<5;$i++) {
+for (my $i=0;$i<50;$i++) {
 	$spinner->spin();
-	sleep(1);
+	sleep(0.05);
 }
 $spinner->reset();
 print "done! :)\n";
