@@ -6,7 +6,7 @@ BEGIN {
   $PortageXS::System::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $PortageXS::System::VERSION = '0.3.0';
+  $PortageXS::System::VERSION = '0.3.1';
 }
 # ABSTRACT: System interactions role for PortageXS
 # -----------------------------------------------------------------------------
@@ -26,7 +26,6 @@ BEGIN {
 #
 # -----------------------------------------------------------------------------
 
-use DirHandle;
 
 use Role::Tiny;
 # Description:
@@ -87,7 +86,17 @@ PortageXS::System - System interactions role for PortageXS
 
 =head1 VERSION
 
-version 0.3.0
+version 0.3.1
+
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"PortageXS::System",
+    "interface":"role"
+}
+
+
+=end MetaPOD::JSON
 
 =head1 AUTHORS
 
